<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="fr_FR" sourcelanguage="">
<context>
    <name>@default</name>
    <message>
        <location filename="../driven-pendulum.py" line="40"/>
        <source>This program sets SQ1 to high resolution mode. WG will be disabled.Frequency can be changed from 0.1 Hz to 50Hz</source>
        <translation type="obsolete">Ceprogramme met SQ1 en mode haute résolution. WG sera désactivé. La fréquence sera changée de 0,1 Hz en 50 Hz</translation>
    </message>
</context>
<context>
    <name>Expt</name>
    <message>
        <location filename="../pnpCEout.py" line="40"/>
        <source>Voltage (V)</source>
        <translation>Tension (V)</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="42"/>
        <source>Current (mA)</source>
        <translation>Courant (mA)</translation>
    </message>
    <message>
        <location filename="../diodeIV.py" line="49"/>
        <source>Zener Diode</source>
        <translation>Diode Zéner</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="73"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="77"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../diodeIV.py" line="60"/>
        <source>FIT with I=Io* exp(qV/nkT)</source>
        <translation>FIT (ajuster) avec I=Io* exp(qV/nkT)</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="85"/>
        <source>Clear Traces</source>
        <translation>Effacer les traces</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="71"/>
        <source>Save Data to</source>
        <translation>Enregistrer les données sous</translation>
    </message>
    <message>
        <location filename="../diodeIV.py" line="80"/>
        <source>diode_iv.txt</source>
        <translation type="obsolete">diode_iv.txt</translation>
    </message>
    <message>
        <location filename="../driven-pendulum.py" line="38"/>
        <source>Set SQ1</source>
        <translation>Régler SQ1</translation>
    </message>
    <message>
        <location filename="../editor.py" line="38"/>
        <source>Execute Code</source>
        <translation>Exécuter le code</translation>
    </message>
    <message>
        <location filename="../editor.py" line="41"/>
        <source>Save Code</source>
        <translation>Enregistrer le code</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="47"/>
        <source>Frequency (Hz)</source>
        <translation>Fréquence (Hz)</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="52"/>
        <source>Amplitude Gain</source>
        <translation>Amplitude, gain</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="67"/>
        <source>Rload =</source>
        <translation type="obsolete">R_charge =</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="101"/>
        <source>Ohm</source>
        <translation>Ω</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="60"/>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="65"/>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="87"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="92"/>
        <source>Number of Steps =</source>
        <translation>Nombre d&apos;étapes</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="120"/>
        <source>filter-data.txt</source>
        <translation type="obsolete">filter-data.txt</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="57"/>
        <source>Time (mS)</source>
        <translation>Temps (ms)</translation>
    </message>
    <message>
        <location filename="../induction.py" line="61"/>
        <source>Select Range of A1</source>
        <translation>Choix du calibre de A1</translation>
    </message>
    <message>
        <location filename="../induction.py" line="64"/>
        <source>4 V</source>
        <translation>4 V</translation>
    </message>
    <message>
        <location filename="../induction.py" line="73"/>
        <source>Start Scanning</source>
        <translation>Démarrer le scan</translation>
    </message>
    <message>
        <location filename="../induction.py" line="93"/>
        <source>induction.txt</source>
        <translation type="obsolete">induction.txt</translation>
    </message>
    <message>
        <location filename="../logger.py" line="54"/>
        <source>Voltage(V)</source>
        <translation>Tension (V)</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="131"/>
        <source>Total Duration</source>
        <translation>Durée totale</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="147"/>
        <source>Seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="142"/>
        <source>Measure every</source>
        <translation>Mesurer toutes les</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="89"/>
        <source>Save Data</source>
        <translation>Enregistrer les données</translation>
    </message>
    <message>
        <location filename="../logger.py" line="125"/>
        <source>logger.txt</source>
        <translation type="obsolete">logger.txt</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="54"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../pendulumVelocity.py" line="55"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="82"/>
        <source>Read every</source>
        <translation>Lire toutes les</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="87"/>
        <source>mS</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="119"/>
        <source>MPU6050.txt</source>
        <translation type="obsolete">MPU6050.txt</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="53"/>
        <source>Vbase (via 100kOhm)</source>
        <translation>V_base (via 100 kΩ)</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="58"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="85"/>
        <source>tran-VI.txt</source>
        <translation type="obsolete">tran-VI.txt</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="99"/>
        <source>Analyze last Trace</source>
        <translation>Analyser la dernière trace</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="47"/>
        <source>Current through R (mA)</source>
        <translation>Courant traversant R (mA)</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="49"/>
        <source>Voltage across R(Volts)</source>
        <translation>Tension aux bornes de R (V)</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="62"/>
        <source>R from A1 to Ground</source>
        <translation>R entre A1 et la masse (GND)</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="74"/>
        <source>Sweep PV1 from</source>
        <translation>Balayer PV1 depuis</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="118"/>
        <source>iv.txt</source>
        <translation type="obsolete">iv.txt</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="111"/>
        <source>Change Voltage</source>
        <translation>Changer la tension</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="118"/>
        <source>Voltage = %5.3f</source>
        <translation>Tension = %5.3f</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="123"/>
        <source>Current = 0 mA</source>
        <translation>Courant = 0 mA</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="155"/>
        <source>Voltage = %5.3f V</source>
        <translation>Tension = %5.3f V</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="157"/>
        <source>Current = %5.3f mA</source>
        <translation>Courant = %5.3f mA</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="54"/>
        <source>Temparature (C)</source>
        <translation>Température (°C)</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="65"/>
        <source>Measure A3</source>
        <translation>Mesurer A3</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="75"/>
        <source>A3 Gain</source>
        <translation>Gain de A3</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="80"/>
        <source>1+10k/Rg</source>
        <translation>1+10k/R_g</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="86"/>
        <source>A3 Offset</source>
        <translation>Décalage (offset) de A3</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="91"/>
        <source>mV </source>
        <translation>mV </translation>
    </message>
    <message>
        <location filename="../pt100.py" line="97"/>
        <source>CCS Value</source>
        <translation>Valeur de CSS</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="102"/>
        <source>mA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../pt100.py" line="109"/>
        <source>Lowest Temp</source>
        <translation>Temp inf</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="125"/>
        <source>deg C</source>
        <translation>°C</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="120"/>
        <source>Highest Temp</source>
        <translation>Temp sup</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="178"/>
        <source>pt100.txt</source>
        <translation type="obsolete">pt100.txt</translation>
    </message>
    <message>
        <location filename="../scope.py" line="509"/>
        <source>%5.3f V</source>
        <translation>%5.3f V</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="59"/>
        <source>Voltage</source>
        <translation>Tension</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="87"/>
        <source>Timebase</source>
        <translation>Balayage</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="92"/>
        <source>mS/div</source>
        <translation>ms/div</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="72"/>
        <source>RCtransient.txt</source>
        <translation>RCtransient.txt</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="87"/>
        <source>0 -&gt; 5V step on OD1</source>
        <translation>Échelon 0 -&gt; 5V sur OD1</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="91"/>
        <source>5 -&gt; 0V step on OD1</source>
        <translation>Échelon 5 -&gt; 0V sur OD1</translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="88"/>
        <source>Calculate RC</source>
        <translation>Calculer RC</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="110"/>
        <source>Clear Data &amp; Traces</source>
        <translation>Effacer données &amp; traces</translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="97"/>
        <source>Resistance =</source>
        <translation>Résistance =</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="126"/>
        <source>messages</source>
        <translation>messages</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="80"/>
        <source>WG</source>
        <translation>WG</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="159"/>
        <source>RLCs-data.txt</source>
        <translation type="obsolete">RLCs-data.txt</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="155"/>
        <source>Impedance Calculator</source>
        <translation>Calculateur d&apos;impédance</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="159"/>
        <source>F (in Hz)</source>
        <translation>f (en Hz)</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="165"/>
        <source>R (in Ohms)</source>
        <translation>R (en Ω)</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="174"/>
        <source>C (in uF)</source>
        <translation>C (en µF)</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="179"/>
        <source>L (in mH)</source>
        <translation>L (en mH)</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="187"/>
        <source>Calculate XL, XC and Fo</source>
        <translation>Calculer Z_L, Z_C et f_0</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="292"/>
        <source>F = %5.1f Hz</source>
        <translation>f = %5.1f Hz</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="288"/>
        <source>Vtotal (A1) = %5.2f V</source>
        <translation>V_total (A1) = %5.2f V</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="289"/>
        <source>Vr (A2) = %5.2f V</source>
        <translation>V_R (A2) = %5.2f V</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="290"/>
        <source>Vlc (A2-A1) = %5.2f V</source>
        <translation>V_LC (A2-A1) = %5.2f V</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="293"/>
        <source>Phase Diff = %5.1f deg</source>
        <translation>Diff phase = %5.1f °</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="296"/>
        <source>Vc (A3-A1) = %5.2f V</source>
        <translation>V_C (A3-A1) = %5.2f V</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="297"/>
        <source>Vl (A2-A3) = %5.2f V</source>
        <translation>V_L (A2-A3) = %5.2f V</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="382"/>
        <source>Invalid Input in some field</source>
        <translation>Entrée invalide dans un champ</translation>
    </message>
    <message>
        <location filename="../RLCtransient.py" line="89"/>
        <source>RLCtransient.txt</source>
        <translation type="obsolete">RLCtransient.txt</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="96"/>
        <source>Rext =</source>
        <translation>R_ext =</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="106"/>
        <source>Analyse last Trace</source>
        <translation>Analyser cette trace</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="37"/>
        <source>Trials</source>
        <translation>Essais</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="39"/>
        <source>Time Period (mSec)</source>
        <translation>Période (ms)</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="83"/>
        <source>Number of trials</source>
        <translation>Nombre d&apos;essais</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="66"/>
        <source>Clear Data and Traces</source>
        <translation>Effacer données &amp; traces</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="85"/>
        <source>rod-pendulum.txt</source>
        <translation type="obsolete">rod-pendulum.txt</translation>
    </message>
    <message>
        <location filename="../scope.py" line="129"/>
        <source>Time: %6.2fmS </source>
        <translation>Temps : %6.2f ms </translation>
    </message>
    <message>
        <location filename="../scope.py" line="138"/>
        <source>%s:%6.2fV </source>
        <translation>%s :%6.2f V </translation>
    </message>
    <message>
        <location filename="../scope.py" line="207"/>
        <source>DC Voltages at A1, A2 and A3</source>
        <translation>Tensions continues en A1, A2 et A3</translation>
    </message>
    <message>
        <location filename="../scope.py" line="222"/>
        <source>Resistance on SEN = </source>
        <translation>Résistance sur SEN = </translation>
    </message>
    <message>
        <location filename="../scope.py" line="229"/>
        <source>Click for Capacitance on IN1</source>
        <translation>Cliquer pour la capacité en IN1</translation>
    </message>
    <message>
        <location filename="../scope.py" line="238"/>
        <source>Click for Frequency on IN2</source>
        <translation>Cliquer pour la fréquence en IN2</translation>
    </message>
    <message>
        <location filename="../scope.py" line="247"/>
        <source>Enable OD1</source>
        <translation>Activer OD1</translation>
    </message>
    <message>
        <location filename="../scope.py" line="250"/>
        <source>Enable CCS</source>
        <translation>Activer CCS</translation>
    </message>
    <message>
        <location filename="../scope.py" line="256"/>
        <source>WG Shape</source>
        <translation>Forme de WG</translation>
    </message>
    <message>
        <location filename="../scope.py" line="265"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="89"/>
        <source>SQ1</source>
        <translation>SQ1</translation>
    </message>
    <message>
        <location filename="../scope.py" line="304"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../scope.py" line="310"/>
        <source>PV1</source>
        <translation>PV1</translation>
    </message>
    <message>
        <location filename="../scope.py" line="335"/>
        <source>Volt</source>
        <translation>Volt</translation>
    </message>
    <message>
        <location filename="../scope.py" line="326"/>
        <source>PV2</source>
        <translation>PV2</translation>
    </message>
    <message>
        <location filename="../scope.py" line="342"/>
        <source>Oscilloscope Channels, Range and Analysis </source>
        <translation>Canaux de l&apos;oscilloscope, calibre et analyse </translation>
    </message>
    <message>
        <location filename="../scope.py" line="388"/>
        <source>Trigger</source>
        <translation>Seuil V</translation>
    </message>
    <message>
        <location filename="../scope.py" line="393"/>
        <source>On</source>
        <translation>Pour</translation>
    </message>
    <message>
        <location filename="../scope.py" line="396"/>
        <source>A1</source>
        <translation>A1</translation>
    </message>
    <message>
        <location filename="../scope.py" line="411"/>
        <source>scope.txt</source>
        <translation type="obsolete">scope.txt</translation>
    </message>
    <message>
        <location filename="../scope.py" line="414"/>
        <source>FFT</source>
        <translation type="obsolete">FFT</translation>
    </message>
    <message>
        <location filename="../scope.py" line="422"/>
        <source>Cross hair</source>
        <translation>Réticule</translation>
    </message>
    <message>
        <location filename="../scope.py" line="426"/>
        <source>Freeze</source>
        <translation>Geler</translation>
    </message>
    <message>
        <location filename="../scope.py" line="428"/>
        <source>A1-A2</source>
        <translation>A1-A2</translation>
    </message>
    <message>
        <location filename="../scope.py" line="491"/>
        <source>%5.2f V, %5.1f Hz</source>
        <translation>%5.2f V, %5.1f Hz</translation>
    </message>
    <message>
        <location filename="../scope.py" line="517"/>
        <source>&lt;100Ohm  or  &gt;100k</source>
        <translation>&lt; 100 Ω  ou  &gt; 100 kΩ</translation>
    </message>
    <message>
        <location filename="../scope.py" line="591"/>
        <source>Fundamental frequency = %5.1f Hz</source>
        <translation>Fréquence fondamentale = %5.1f Hz</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="165"/>
        <source>Frequency Spectrum</source>
        <translation>Spectre de fréquence</translation>
    </message>
    <message>
        <location filename="../scope.py" line="782"/>
        <source>%6.1f pF</source>
        <translation type="obsolete">%6.1f pF</translation>
    </message>
    <message>
        <location filename="../scope.py" line="823"/>
        <source>%5.1fHz %4.1f%%</source>
        <translation>%5.1f Hz %4.1f%%</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="101"/>
        <source>Change of Freqency effected
only after Enable/Disable controls.
shows the actual frequency set.
</source>
        <translation>Changement de fréquence possible
seulement après l&apos;activation/désactivation des contrôles.
Affichage de l&apos;ensemble de fréquences actuel.
</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="140"/>
        <source>sound-beats.txt</source>
        <translation type="obsolete">sound-beats.txt</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="49"/>
        <source>Amplitude (V)</source>
        <translation>Amplitude (V)</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="76"/>
        <source>in</source>
        <translation>en</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="81"/>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="115"/>
        <source>freq-resp.txt</source>
        <translation type="obsolete">freq-resp.txt</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="176"/>
        <source>Frequency = %5.0f Hz V = %5.3f</source>
        <translation>Fréquence = %5.0f Hz ; V = %5.3f</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="86"/>
        <source>sound-velocity.txt</source>
        <translation type="obsolete">sound-velocity.txt</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="97"/>
        <source>Enable Measurements</source>
        <translation>Activer les mesures</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="174"/>
        <source>Phase Shift = %5.1f deg</source>
        <translation type="obsolete">Déphasage = %5.1f °</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="38"/>
        <source>Time (Sec)</source>
        <translation>Temps (s)</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="40"/>
        <source>Distance(cm)</source>
        <translation>Distance (cm)</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="51"/>
        <source>Y-axis from 0 to</source>
        <translation>Axe Y de 0 à</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="56"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="63"/>
        <source>Measure during</source>
        <translation>Mesurer pendant</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="68"/>
        <source>Secs</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="81"/>
        <source>Fit Curve using Sine</source>
        <translation>FIT avec une fonction sinus</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="100"/>
        <source>sr04-data.txt</source>
        <translation type="obsolete">sr04-data.txt</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="55"/>
        <source>Voltage  A2</source>
        <translation>Tension A2</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="143"/>
        <source>Voltage (A2)</source>
        <translation>Tension (A2)</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="75"/>
        <source>XYplot.txt</source>
        <translation>XYplot.txt</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="93"/>
        <source>Voltage range</source>
        <translation>Calibre (tension)</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="98"/>
        <source>Volts</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="103"/>
        <source>show (A1-A2) Vs A2</source>
        <translation>montrer (A1-A2) en fonction de A2</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="141"/>
        <source>Voltage (A1-A2)</source>
        <translation>Tension (A1-A2)</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="169"/>
        <source>Xmax = %5.3f V</source>
        <translation>Xmax = %5.3f V</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="170"/>
        <source>Ymax = %5.3f V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../scope.py" line="528"/>
        <source>Communication Error. Try Reconnect from the Device menu</source>
        <translation type="obsolete">Erreur de communication. Tentez une reconnexion depuis le menu de périphériques</translation>
    </message>
    <message>
        <location filename="../scope.py" line="478"/>
        <source>%s input is clipped. Increase range</source>
        <translation>L&apos;entrée %s est saturée. Augmentez le calibre</translation>
    </message>
    <message>
        <location filename="../scope.py" line="515"/>
        <source>%5.0f Ohm</source>
        <translation>%5.0f Ω</translation>
    </message>
    <message>
        <location filename="../scope.py" line="551"/>
        <source>Capture or fit Error, Try reconnect</source>
        <translation type="obsolete">Erreur de capture ou de FIT. Tentez une reconnexion</translation>
    </message>
    <message>
        <location filename="../scope.py" line="558"/>
        <source>Range of %s set to %s</source>
        <translation type="obsolete">Calibre de %s réglé à %s</translation>
    </message>
    <message>
        <location filename="../scope.py" line="571"/>
        <source>FFT ErrCommunication Error. Try Reconnect from the Device menu</source>
        <translation type="obsolete">Erreur de communication FFT. Reconnecter depuis le menu de périphériques</translation>
    </message>
    <message>
        <location filename="../scope.py" line="596"/>
        <source>FFT Error</source>
        <translation>Erreur de FFT</translation>
    </message>
    <message>
        <location filename="../npnCEout.py" line="192"/>
        <source>Traces saved to %s</source>
        <translation type="obsolete">Traces enregistrées dans %s</translation>
    </message>
    <message>
        <location filename="../scope.py" line="703"/>
        <source>sqr1 set to %5.1f</source>
        <translation type="obsolete">SQ1 réglé à %5.1f</translation>
    </message>
    <message>
        <location filename="../scope.py" line="728"/>
        <source>AWG set to %6.2f Hz</source>
        <translation type="obsolete">AWG réglé à %6.2f Hz</translation>
    </message>
    <message>
        <location filename="../scope.py" line="751"/>
        <source>Output Changed from WG to SQ2</source>
        <translation>Sortie changée de WG à SQ2</translation>
    </message>
    <message>
        <location filename="../scope.py" line="800"/>
        <source>Capacitance too high or short to ground</source>
        <translation>Capacité excessive ou court-circuit à la masse</translation>
    </message>
    <message>
        <location filename="../scope.py" line="825"/>
        <source>No signal</source>
        <translation>Pas de signal</translation>
    </message>
    <message>
        <location filename="../logger.py" line="164"/>
        <source>Data logger plot completed</source>
        <translation>Graphique de l&apos;enregistreur terminé</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="171"/>
        <source>Invalid Duration</source>
        <translation>Durée invalide</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="263"/>
        <source>Invalid time interval between reads</source>
        <translation>Intervalle de temps entre lectures invalide</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="191"/>
        <source>Started Measurements</source>
        <translation>Démarré les mesures</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="198"/>
        <source>User Stopped</source>
        <translation>L&apos;utilisateur a arrêté</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="205"/>
        <source>Cleared Traces and Data</source>
        <translation>Effacé les traces et les données</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="218"/>
        <source>Curve fitting result rejected</source>
        <translation>Résultat du FIT rejetés</translation>
    </message>
    <message>
        <location filename="../RLCsteadystate.py" line="282"/>
        <source>Data Analysis Error</source>
        <translation>Erreur d&apos;analyse de données</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="223"/>
        <source>Error. Try Device-&gt;Reconnect</source>
        <translation>Erreur. Tentez Périphérique -&gt; Reconnexion</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="31"/>
        <source>Ax</source>
        <translation>Ax</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="32"/>
        <source>Ay</source>
        <translation>Ay</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="33"/>
        <source>Az</source>
        <translation>Az</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="34"/>
        <source>Temperature</source>
        <translation>Température</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="35"/>
        <source>Vx</source>
        <translation>Vx</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="36"/>
        <source>Vy</source>
        <translation>Vy</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="37"/>
        <source>Vz</source>
        <translation>Vz</translation>
    </message>
    <message>
        <location filename="../driven-pendulum.py" line="33"/>
        <source>This program sets SQ1 to high resolution mode. WG will be disabled.Frequency can be changed from 0.1 Hz to 50Hz</source>
        <translation>Ceprogramme met SQ1 en mode haute résolution. WG sera désactivé. La fréquence sera changée de 0,1 Hz en 50 Hz</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="105"/>
        <source>Enable WG</source>
        <translation>Activer WG</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="109"/>
        <source>Enable SQ1</source>
        <translation>activer SQ1</translation>
    </message>
    <message>
        <location filename="../diodeIV.py" line="108"/>
        <source>Fitted with Diode Equation : Io = </source>
        <translation>Fait un FIT pour la diode, équation : Io = </translation>
    </message>
    <message>
        <location filename="../diodeIV.py" line="108"/>
        <source> mA , Ideality factor = </source>
        <translation> mA, facteur d&apos;idéalité = </translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="139"/>
        <source>Analysis failed. Could not fit data</source>
        <translation>Échec de l&apos;analyse. Fit des données impossible</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="117"/>
        <source>Completed plotting I-V</source>
        <translation>Graphique I U terminé</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="159"/>
        <source>Started</source>
        <translation>Démarré</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="275"/>
        <source>No Traces available for saving</source>
        <translation>Pas de trace disponible à sauvegarder</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="182"/>
        <source>Traces saved to </source>
        <translation>Traces enregistrées sous </translation>
    </message>
    <message>
        <location filename="../scope.py" line="724"/>
        <source>sqr1 set to </source>
        <translation>SQR1 réglé à </translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="193"/>
        <source> Hz</source>
        <translation> Hz</translation>
    </message>
    <message>
        <location filename="../editor.py" line="69"/>
        <source>Code saved to </source>
        <translation>Code enregistré sous </translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="166"/>
        <source>Frequency = </source>
        <translation>Fréquence = </translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="190"/>
        <source>Fit failed</source>
        <translation>Échec du FIT</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="213"/>
        <source>completed</source>
        <translation>terminé</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="216"/>
        <source>Invalid Frequency limits</source>
        <translation>Limites de fréquence non valides</translation>
    </message>
    <message>
        <location filename="../filterCircuit.py" line="258"/>
        <source>user Stopped</source>
        <translation>L&apos;utilisateur a arrêté</translation>
    </message>
    <message>
        <location filename="../induction.py" line="129"/>
        <source>Noise = </source>
        <translation>Bruit = </translation>
    </message>
    <message>
        <location filename="../induction.py" line="129"/>
        <source> V. Drop the Magnet until a trace is captured</source>
        <translation> V. Laisser tomber l&apos;aimant jusqu&apos;à ce qu&apos;une trace soit capturée</translation>
    </message>
    <message>
        <location filename="../induction.py" line="144"/>
        <source>Induced voltage </source>
        <translation>Tension induite </translation>
    </message>
    <message>
        <location filename="../induction.py" line="147"/>
        <source>Detected voltage above threshold. Peak voltages: </source>
        <translation>Tension détectée plus haute que le seuil. Tension de crête : </translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="136"/>
        <source>I2C device communication error</source>
        <translation>Erreur de communication I2C</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="154"/>
        <source>MPU6050 data plot completed</source>
        <translation>Données du MPU6050 tracées</translation>
    </message>
    <message>
        <location filename="../MPU6050.py" line="169"/>
        <source>Invalid Duration or Time between reads (&gt; 10 mSec)</source>
        <translation>Durée non valide entre les échantillons (&gt; 10 ms)</translation>
    </message>
    <message>
        <location filename="../npnCEout.py" line="137"/>
        <source>Base valtage shold be from .5 to 3</source>
        <translation>La tension de base devrait être entre 5 et 3</translation>
    </message>
    <message>
        <location filename="../npnCEout.py" line="140"/>
        <source>Invalid Base valtage, shold be from .5 to 3</source>
        <translation>Tension de base non valide ; elle doit être entre 5 et 3</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="137"/>
        <source>Frequency of Oscillation = </source>
        <translation>Fréquence de l&apos;oscillation  = </translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="137"/>
        <source> Hz. Damping Factor = </source>
        <translation> Hz. Facteur d&apos;amortissement = </translation>
    </message>
    <message>
        <location filename="../pendulumVelocity.py" line="166"/>
        <source>Time Vs Angular velocity plot completed</source>
        <translation>Graphique temps/vitesse angulaire tracé</translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="170"/>
        <source>Slope of the Line (dV/dI) = </source>
        <translation>Pente de la ligne (dV/dt) = </translation>
    </message>
    <message>
        <location filename="../plotIV.py" line="222"/>
        <source>Err</source>
        <translation>Err</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="136"/>
        <source>Base valtage shold be from -0.5 to -3</source>
        <translation>La tension de base devrait être entre -0,5 et -3</translation>
    </message>
    <message>
        <location filename="../pnpCEout.py" line="139"/>
        <source>Invalid Base valtage, shold be from -0.5 to -3</source>
        <translation>Tension de base invalide, elle devrait être entre -0,5 et -3</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="241"/>
        <source>Time Vs Temperature plot completed</source>
        <translation>Graphique temps/température tracé</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="270"/>
        <source>Invalid temperature limit</source>
        <translation>Limite de température non valide</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="277"/>
        <source>Invalid Offset or Gain</source>
        <translation>Décalage ou gain non valides</translation>
    </message>
    <message>
        <location filename="../pt100.py" line="283"/>
        <source>Invalid CCS input</source>
        <translation>Valeur non valide pour CCS</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="121"/>
        <source>No data to analyze.</source>
        <translation>Pas de données à analyser.</translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="149"/>
        <source>Fitted data with V=Vo*exp(-t/RC). RC = </source>
        <translation>FIT des données avec V=Vo*exp(-t/RC). RC = </translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="149"/>
        <source> mSec</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="151"/>
        <source>Failed to fit the curve with V=Vo*exp(-t/RC)</source>
        <translation>Échec du fit avec V=Vo*exp(-t/RC)</translation>
    </message>
    <message>
        <location filename="../RCtransient.py" line="184"/>
        <source>Cleared Data and Traces</source>
        <translation>Effacé les données et les traces</translation>
    </message>
    <message>
        <location filename="../XYplot.py" line="193"/>
        <source>AWG set to </source>
        <translation>AWG réglé à </translation>
    </message>
    <message>
        <location filename="../RLCtransient.py" line="144"/>
        <source>Resonant Frequency = </source>
        <translation>Fréquence de résonance = </translation>
    </message>
    <message>
        <location filename="../RLCtransient.py" line="144"/>
        <source> kHz Damping factor= </source>
        <translation> kHz, facteur d&apos;amortissement = </translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="131"/>
        <source>Failed to fit the curve</source>
        <translation>Échec du FIT de la courbe</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="150"/>
        <source>Enter a valid Resistance</source>
        <translation>Entrer une résistance valide</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="180"/>
        <source>L/R = </source>
        <translation>L/R = </translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="180"/>
        <source> mSec : Rind = </source>
        <translation> ms ; Rind = </translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="180"/>
        <source> Ohm : L = </source>
        <translation> Ω : L = </translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="180"/>
        <source> mH</source>
        <translation> mH</translation>
    </message>
    <message>
        <location filename="../RLtransient.py" line="183"/>
        <source>Failed to fit the curve with V=Vo*exp(-t*L/R)</source>
        <translation>Échec du fit avec V=Vo*exp(-t*L/R)</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="169"/>
        <source>Completed</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="170"/>
        <source>Invalid Number</source>
        <translation type="obsolete">Nombre non valide</translation>
    </message>
    <message>
        <location filename="../scope.py" line="566"/>
        <source>Range of</source>
        <translation>Intervalle de</translation>
    </message>
    <message>
        <location filename="../scope.py" line="566"/>
        <source> set to </source>
        <translation> réglé à </translation>
    </message>
    <message>
        <location filename="../scope.py" line="804"/>
        <source> pF</source>
        <translation> pF</translation>
    </message>
    <message>
        <location filename="../soundBeats.py" line="170"/>
        <source>FFT err</source>
        <translation>err FFT</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="189"/>
        <source>Trace saved to </source>
        <translation>Traces enregistrées sous </translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="195"/>
        <source>Completed in </source>
        <translation>Terminé en </translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="195"/>
        <source> Seconds</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="222"/>
        <source>Invalid Time interval</source>
        <translation>Intervalle de temps non valide</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="235"/>
        <source>Increase time interval to </source>
        <translation>Augmenter l&apos;intervalle de temps à </translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="235"/>
        <source> or Reduce frequency span</source>
        <translation> ou réduire l&apos;intervalle de fréquence</translation>
    </message>
    <message>
        <location filename="../soundFreqResp.py" line="247"/>
        <source> mS at each step</source>
        <translation> ms à chaque étape</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="172"/>
        <source>Phase Shift = </source>
        <translation>Déphasage = </translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="127"/>
        <source>Sine Fit Result: Frequency </source>
        <translation>FIT sinusoïdal : fréquence </translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="156"/>
        <source>Time vs Distance plot completed</source>
        <translation>Graphique temps/distance tracé</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="212"/>
        <source>No data to save</source>
        <translation>Pas de données à enregistrer</translation>
    </message>
    <message>
        <location filename="../sr04dist.py" line="209"/>
        <source>Measurement in progress</source>
        <translation>Mesures en cours</translation>
    </message>
    <message>
        <location filename="../RLCtransient.py" line="99"/>
        <source>Analyse latest Data</source>
        <translation>Analyser les données récentes</translation>
    </message>
    <message>
        <location filename="../RLCtransient.py" line="107"/>
        <source>Clear Data</source>
        <translation>Effacer les données</translation>
    </message>
    <message>
        <location filename="../scope.py" line="406"/>
        <source>Save Traces</source>
        <translation>Enregistrer les traces</translation>
    </message>
    <message>
        <location filename="../scope.py" line="414"/>
        <source>Fourier Transform</source>
        <translation>Transformée de Fourier</translation>
    </message>
    <message>
        <location filename="../scope.py" line="807"/>
        <source> nF</source>
        <translation> nF</translation>
    </message>
    <message>
        <location filename="../scope.py" line="810"/>
        <source> uF</source>
        <translation> µF</translation>
    </message>
    <message>
        <location filename="../soundVelocity.py" line="177"/>
        <source>Disable before Saving</source>
        <translation>Désactiver avant l&apos;enregistrement</translation>
    </message>
    <message>
        <location filename="../main.py" line="19"/>
        <source>Voltage measurement</source>
        <translation type="obsolete">Mesure de tension</translation>
    </message>
    <message>
        <location filename="../main.py" line="20"/>
        <source>Resistance measurement</source>
        <translation type="obsolete">Mesure de résistance</translation>
    </message>
    <message>
        <location filename="../main.py" line="21"/>
        <source>Resistors in Series</source>
        <translation type="obsolete">Résistances en série</translation>
    </message>
    <message>
        <location filename="../main.py" line="22"/>
        <source>Resistors in Parallel</source>
        <translation type="obsolete">Résistances en parallèle</translation>
    </message>
    <message>
        <location filename="../main.py" line="23"/>
        <source>Capacitance measurement</source>
        <translation type="obsolete">Mesure de capacité</translation>
    </message>
    <message>
        <location filename="../main.py" line="24"/>
        <source>Capacitors in Series</source>
        <translation type="obsolete">Condensateurs en série</translation>
    </message>
    <message>
        <location filename="../main.py" line="25"/>
        <source>Capacitors in Parallel</source>
        <translation type="obsolete">Condensateurs en parallèle</translation>
    </message>
    <message>
        <location filename="../main.py" line="26"/>
        <source>Resistance by Ohm&apos;s law</source>
        <translation type="obsolete">Résistance par la loi d&apos;Ohm</translation>
    </message>
    <message>
        <location filename="../main.py" line="27"/>
        <source>Direct and Alternating Currents</source>
        <translation type="obsolete">Courants continu et alternatif</translation>
    </message>
    <message>
        <location filename="../main.py" line="28"/>
        <source>AC mains pickup</source>
        <translation type="obsolete">Influence de la tension du secteur</translation>
    </message>
    <message>
        <location filename="../main.py" line="29"/>
        <source>Separating AC and DC</source>
        <translation type="obsolete">Séparation du continue et de l&apos;alternatif</translation>
    </message>
    <message>
        <location filename="../main.py" line="30"/>
        <source>Conducting Human body</source>
        <translation type="obsolete">Conductance du corps humain</translation>
    </message>
    <message>
        <location filename="../main.py" line="31"/>
        <source>Resistance of Human body</source>
        <translation type="obsolete">Résistance du corps humain</translation>
    </message>
    <message>
        <location filename="../main.py" line="32"/>
        <source>Light Dependent Resistor</source>
        <translation type="obsolete">Photorésistance</translation>
    </message>
    <message>
        <location filename="../main.py" line="33"/>
        <source>Lemon Cell</source>
        <translation type="obsolete">Pile au citron</translation>
    </message>
    <message>
        <location filename="../main.py" line="34"/>
        <source>Simple AC generator</source>
        <translation type="obsolete">Générateur alternatif simple</translation>
    </message>
    <message>
        <location filename="../main.py" line="35"/>
        <source>Transformer</source>
        <translation type="obsolete">Transformateur</translation>
    </message>
    <message>
        <location filename="../main.py" line="36"/>
        <source>Resistance of Water</source>
        <translation type="obsolete">Résistance de l&apos;eau</translation>
    </message>
    <message>
        <location filename="../main.py" line="37"/>
        <source>Generating Sound</source>
        <translation type="obsolete">Générer un son</translation>
    </message>
    <message>
        <location filename="../main.py" line="38"/>
        <source>Digitizing Sound</source>
        <translation type="obsolete">Numériser un son</translation>
    </message>
    <message>
        <location filename="../main.py" line="39"/>
        <source>Stroboscope</source>
        <translation type="obsolete">Stroboscope</translation>
    </message>
    <message>
        <location filename="../main.py" line="57"/>
        <source>Oscilloscope</source>
        <translation type="obsolete">Oscilloscope</translation>
    </message>
    <message>
        <location filename="../main.py" line="50"/>
        <source>Diode Characteristics</source>
        <translation type="obsolete">Caractéristique d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="51"/>
        <source>NPN Output Characteristics</source>
        <translation type="obsolete">Caractéristique d&apos;un transistor NPN</translation>
    </message>
    <message>
        <location filename="../main.py" line="52"/>
        <source>PNP Output Characteristics</source>
        <translation type="obsolete">Caractéristique d&apos;un transistor PNP</translation>
    </message>
    <message>
        <location filename="../main.py" line="58"/>
        <source>Halfwave Rectifier</source>
        <translation type="obsolete">Redressement demi-onde</translation>
    </message>
    <message>
        <location filename="../main.py" line="117"/>
        <source>Fullwave Rectifier</source>
        <translation type="obsolete">Redressement complet</translation>
    </message>
    <message>
        <location filename="../main.py" line="60"/>
        <source>Diode Clipping</source>
        <translation type="obsolete">Écrêtage à l&apos;aide d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="61"/>
        <source>Diode Clamping</source>
        <translation type="obsolete">Décalage de tension à l&apos;aide d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="62"/>
        <source>IC555 Multivibrator</source>
        <translation type="obsolete">Multivibrateur IC555</translation>
    </message>
    <message>
        <location filename="../main.py" line="63"/>
        <source>Inverting Amplifier</source>
        <translation type="obsolete">Amplificateur inverseur</translation>
    </message>
    <message>
        <location filename="../main.py" line="64"/>
        <source>Non-Inverting Amplifier</source>
        <translation type="obsolete">Amplificateur non-inverseur</translation>
    </message>
    <message>
        <location filename="../main.py" line="65"/>
        <source>Integrator using Op-Amp</source>
        <translation type="obsolete">Intégrateur à base d&apos;ampli. op</translation>
    </message>
    <message>
        <location filename="../main.py" line="66"/>
        <source>Logic Gates</source>
        <translation type="obsolete">Portes logiques</translation>
    </message>
    <message>
        <location filename="../main.py" line="67"/>
        <source>Clock Divider Circuit</source>
        <translation type="obsolete">Circuit diviseur d&apos;horloge</translation>
    </message>
    <message>
        <location filename="../main.py" line="71"/>
        <source>Plot I-V Curve</source>
        <translation type="obsolete">Tracé d&apos;une courbe courant-tension</translation>
    </message>
    <message>
        <location filename="../main.py" line="72"/>
        <source>XY Plotting</source>
        <translation type="obsolete">Tracé XY</translation>
    </message>
    <message>
        <location filename="../main.py" line="73"/>
        <source>RLC Steady state response</source>
        <translation type="obsolete">Circuit RLC en régime permanent</translation>
    </message>
    <message>
        <location filename="../main.py" line="74"/>
        <source>RC Transient response</source>
        <translation type="obsolete">Circuit RC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="75"/>
        <source>RL Transient response</source>
        <translation type="obsolete">Circuit RL en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="76"/>
        <source>RLC transient response</source>
        <translation type="obsolete">Circuit RLC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="77"/>
        <source>Frequency Response of Filter Circuit</source>
        <translation type="obsolete">Réponse en fréquence d&apos;un circuit de filtrage</translation>
    </message>
    <message>
        <location filename="../main.py" line="78"/>
        <source>Electromagnetic Induction</source>
        <translation type="obsolete">Induction électromagnétique</translation>
    </message>
    <message>
        <location filename="../main.py" line="82"/>
        <source>Frequency Response of Piezo Buzzer</source>
        <translation type="obsolete">Réponse en fréquence d&apos;un buzzer piézo</translation>
    </message>
    <message>
        <location filename="../main.py" line="83"/>
        <source>Velocity of Sound</source>
        <translation type="obsolete">Vitesse du son</translation>
    </message>
    <message>
        <location filename="../main.py" line="84"/>
        <source>Sound beats</source>
        <translation type="obsolete">Battements sonores</translation>
    </message>
    <message>
        <location filename="../main.py" line="88"/>
        <source>Rod Pendulum with Light barrier</source>
        <translation type="obsolete">Pendule à barre avec une détecteur lumineux</translation>
    </message>
    <message>
        <location filename="../main.py" line="89"/>
        <source>Pendulum Wavefrorm</source>
        <translation type="obsolete">Signal d&apos;un pendule</translation>
    </message>
    <message>
        <location filename="../main.py" line="90"/>
        <source>Driven Pendulum resonance</source>
        <translation type="obsolete">Résonance d&apos;un pendule entretenu</translation>
    </message>
    <message>
        <location filename="../main.py" line="91"/>
        <source>Distance by HY-SRF04 Echo module</source>
        <translation type="obsolete">Distance à l&apos;aide d&apos;un module d&apos;écho SFR04</translation>
    </message>
    <message>
        <location filename="../main.py" line="95"/>
        <source>Temperatue, PT100 Sensor</source>
        <translation type="obsolete">Température, sonde Pt100</translation>
    </message>
    <message>
        <location filename="../main.py" line="96"/>
        <source>Data Logger</source>
        <translation type="obsolete">Enregistreur de données</translation>
    </message>
    <message>
        <location filename="../main.py" line="100"/>
        <source>MPU-6050 Acccn, Velocity and Temp</source>
        <translation type="obsolete">MPU-6050 : Acccn, Vit. et Temp</translation>
    </message>
    <message>
        <location filename="../main.py" line="104"/>
        <source>Read Inputs</source>
        <translation type="obsolete">Lire les entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="105"/>
        <source>Set DC Voltages</source>
        <translation type="obsolete">Régler les tensions continues</translation>
    </message>
    <message>
        <location filename="../main.py" line="106"/>
        <source>Capture Single Input</source>
        <translation type="obsolete">Capturer une seule entrée</translation>
    </message>
    <message>
        <location filename="../main.py" line="107"/>
        <source>Capture Two Inputs</source>
        <translation type="obsolete">Capturer deux entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="108"/>
        <source>Capture Four Inputs</source>
        <translation type="obsolete">Capturer quatre entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="109"/>
        <source>Triangular Waveform</source>
        <translation type="obsolete">Signal triangulaire</translation>
    </message>
    <message>
        <location filename="../main.py" line="110"/>
        <source>Arbitrary Waveform</source>
        <translation type="obsolete">Signal arbitraire</translation>
    </message>
    <message>
        <location filename="../main.py" line="111"/>
        <source>Waveform Table</source>
        <translation type="obsolete">Table d&apos;ondes</translation>
    </message>
    <message>
        <location filename="../main.py" line="112"/>
        <source>RC Transient</source>
        <translation type="obsolete">RC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="113"/>
        <source>RL Transient</source>
        <translation type="obsolete">RL en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="114"/>
        <source>RC Integration</source>
        <translation type="obsolete">Intégration RC</translation>
    </message>
    <message>
        <location filename="../main.py" line="115"/>
        <source>Clipping with Diode</source>
        <translation type="obsolete">Écrêtage à diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="116"/>
        <source>Clamping with Diode</source>
        <translation type="obsolete">Décaleur à diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="118"/>
        <source>NPN Ib vs IC plot</source>
        <translation type="obsolete">Tracé Ib vs Ic (NPN)</translation>
    </message>
    <message>
        <location filename="../pendulumVelocity.py" line="86"/>
        <source>
Set SQ1 Frequency
For Driven Pendulum Expt.</source>
        <translation>
Régler la fréquence SQ1
Pour l&apos;expe. de pendule forcé.</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="56"/>
        <source>Pendulum length</source>
        <translation>Longueur du pendule</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="154"/>
        <source>Timeout</source>
        <translation>Délai max</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="185"/>
        <source>Invalid Number of trials</source>
        <translation>Nombre d&apos;essais invalide</translation>
    </message>
    <message>
        <location filename="../rodPendulum.py" line="191"/>
        <source>Invalid Length</source>
        <translation>longueur invalide</translation>
    </message>
</context>
<context>
    <name>HelloButton</name>
    <message>
        <location filename="../hello.py" line="18"/>
        <source>Hello</source>
        <translation type="obsolete">Bonjour</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.py" line="168"/>
        <source>Show PopUp Help Window</source>
        <translation type="obsolete">Montrer la fenêtre d&apos;aide</translation>
    </message>
    <message>
        <location filename="../main.py" line="239"/>
        <source>Failed to load scope</source>
        <translation>Échec de chargement de l&apos;oscillo</translation>
    </message>
    <message>
        <location filename="../main.py" line="270"/>
        <source>Failed to load %s</source>
        <translation>Échec de chargement de %s</translation>
    </message>
    <message>
        <location filename="../main.py" line="320"/>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
    <message>
        <location filename="../main.py" line="325"/>
        <source>School Expts</source>
        <translation>Exp. scolaires</translation>
    </message>
    <message>
        <location filename="../main.py" line="329"/>
        <source>Electronics</source>
        <translation>Électronique</translation>
    </message>
    <message>
        <location filename="../main.py" line="336"/>
        <source>Electrical</source>
        <translation>Électricité</translation>
    </message>
    <message>
        <location filename="../main.py" line="340"/>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <location filename="../main.py" line="344"/>
        <source>Mechanics</source>
        <translation>Mécanique</translation>
    </message>
    <message>
        <location filename="../main.py" line="348"/>
        <source>Other Expts</source>
        <translation>Autres expériences</translation>
    </message>
    <message>
        <location filename="../main.py" line="352"/>
        <source>I2C Modules</source>
        <translation>Modules I2C</translation>
    </message>
    <message>
        <location filename="../main.py" line="356"/>
        <source>PythonCode</source>
        <translation>Code Python</translation>
    </message>
    <message>
        <location filename="../main.py" line="321"/>
        <source>Reconnect</source>
        <translation>Reconnexion</translation>
    </message>
    <message>
        <location filename="../main.py" line="198"/>
        <source>Enable PopUp Help Window</source>
        <translation>Active la fenêtre d&apos;aide surgissante</translation>
    </message>
    <message>
        <location filename="../main.py" line="322"/>
        <source>LightBackGround next time</source>
        <translation>Fond clair (après redémarrage)</translation>
    </message>
    <message>
        <location filename="../main.py" line="323"/>
        <source>DarkBackGround next time</source>
        <translation>Fond sombre (après redémarrage)</translation>
    </message>
    <message>
        <location filename="../main.py" line="310"/>
        <source>No immediate application</source>
        <translation>L&apos;application n&apos;est pas immédiate</translation>
    </message>
    <message>
        <location filename="../main.py" line="298"/>
        <source>Please restart the application to lighten the screen&apos;s background</source>
        <translation>Veuillez relancer l&apos;application pour éclaircir le fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../main.py" line="310"/>
        <source>Please restart the application to darken the screen&apos;s background.</source>
        <translation>Veuillez relancer l&apos;application pour assombrir le fond d&apos;écran.</translation>
    </message>
    <message>
        <location filename="../main.py" line="19"/>
        <source>Voltage measurement</source>
        <translation>Mesure de tension</translation>
    </message>
    <message>
        <location filename="../main.py" line="20"/>
        <source>Resistance measurement</source>
        <translation>Mesure de résistance</translation>
    </message>
    <message>
        <location filename="../main.py" line="21"/>
        <source>Resistors in Series</source>
        <translation>Résistances en série</translation>
    </message>
    <message>
        <location filename="../main.py" line="22"/>
        <source>Resistors in Parallel</source>
        <translation>Résistances en parallèle</translation>
    </message>
    <message>
        <location filename="../main.py" line="23"/>
        <source>Capacitance measurement</source>
        <translation>Mesure de capacité</translation>
    </message>
    <message>
        <location filename="../main.py" line="24"/>
        <source>Capacitors in Series</source>
        <translation>Condensateurs en série</translation>
    </message>
    <message>
        <location filename="../main.py" line="25"/>
        <source>Capacitors in Parallel</source>
        <translation>Condensateurs en parallèle</translation>
    </message>
    <message>
        <location filename="../main.py" line="26"/>
        <source>Resistance by Ohm&apos;s law</source>
        <translation>Résistance par la loi d&apos;Ohm</translation>
    </message>
    <message>
        <location filename="../main.py" line="27"/>
        <source>Direct and Alternating Currents</source>
        <translation>Courants continu et alternatif</translation>
    </message>
    <message>
        <location filename="../main.py" line="28"/>
        <source>AC mains pickup</source>
        <translation>Influence de la tension du secteur</translation>
    </message>
    <message>
        <location filename="../main.py" line="29"/>
        <source>Separating AC and DC</source>
        <translation>Séparation du continue et de l&apos;alternatif</translation>
    </message>
    <message>
        <location filename="../main.py" line="30"/>
        <source>Conducting Human body</source>
        <translation>Conductance du corps humain</translation>
    </message>
    <message>
        <location filename="../main.py" line="31"/>
        <source>Resistance of Human body</source>
        <translation>Résistance du corps humain</translation>
    </message>
    <message>
        <location filename="../main.py" line="32"/>
        <source>Light Dependent Resistor</source>
        <translation>Photorésistance</translation>
    </message>
    <message>
        <location filename="../main.py" line="33"/>
        <source>Lemon Cell</source>
        <translation>Pile au citron</translation>
    </message>
    <message>
        <location filename="../main.py" line="34"/>
        <source>Simple AC generator</source>
        <translation>Générateur alternatif simple</translation>
    </message>
    <message>
        <location filename="../main.py" line="35"/>
        <source>Transformer</source>
        <translation>Transformateur</translation>
    </message>
    <message>
        <location filename="../main.py" line="36"/>
        <source>Resistance of Water</source>
        <translation>Résistance de l&apos;eau</translation>
    </message>
    <message>
        <location filename="../main.py" line="37"/>
        <source>Generating Sound</source>
        <translation>Générer un son</translation>
    </message>
    <message>
        <location filename="../main.py" line="38"/>
        <source>Digitizing Sound</source>
        <translation>Numériser un son</translation>
    </message>
    <message>
        <location filename="../main.py" line="39"/>
        <source>Stroboscope</source>
        <translation>Stroboscope</translation>
    </message>
    <message>
        <location filename="../main.py" line="57"/>
        <source>Oscilloscope</source>
        <translation>Oscilloscope</translation>
    </message>
    <message>
        <location filename="../main.py" line="50"/>
        <source>Diode Characteristics</source>
        <translation>Caractéristique d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="51"/>
        <source>NPN Output Characteristics</source>
        <translation>Caractéristique d&apos;un transistor NPN</translation>
    </message>
    <message>
        <location filename="../main.py" line="52"/>
        <source>PNP Output Characteristics</source>
        <translation>Caractéristique d&apos;un transistor PNP</translation>
    </message>
    <message>
        <location filename="../main.py" line="58"/>
        <source>Halfwave Rectifier</source>
        <translation>Redressement demi-onde</translation>
    </message>
    <message>
        <location filename="../main.py" line="118"/>
        <source>Fullwave Rectifier</source>
        <translation>Redressement complet</translation>
    </message>
    <message>
        <location filename="../main.py" line="60"/>
        <source>Diode Clipping</source>
        <translation>Écrêtage à l&apos;aide d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="61"/>
        <source>Diode Clamping</source>
        <translation>Décalage de tension à l&apos;aide d&apos;une diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="62"/>
        <source>IC555 Multivibrator</source>
        <translation>Multivibrateur IC555</translation>
    </message>
    <message>
        <location filename="../main.py" line="64"/>
        <source>Inverting Amplifier</source>
        <translation>Amplificateur inverseur</translation>
    </message>
    <message>
        <location filename="../main.py" line="65"/>
        <source>Non-Inverting Amplifier</source>
        <translation>Amplificateur non-inverseur</translation>
    </message>
    <message>
        <location filename="../main.py" line="66"/>
        <source>Integrator using Op-Amp</source>
        <translation>Intégrateur à base d&apos;ampli. op</translation>
    </message>
    <message>
        <location filename="../main.py" line="67"/>
        <source>Logic Gates</source>
        <translation>Portes logiques</translation>
    </message>
    <message>
        <location filename="../main.py" line="68"/>
        <source>Clock Divider Circuit</source>
        <translation>Circuit diviseur d&apos;horloge</translation>
    </message>
    <message>
        <location filename="../main.py" line="72"/>
        <source>Plot I-V Curve</source>
        <translation>Tracé d&apos;une courbe courant-tension</translation>
    </message>
    <message>
        <location filename="../main.py" line="73"/>
        <source>XY Plotting</source>
        <translation>Tracé XY</translation>
    </message>
    <message>
        <location filename="../main.py" line="74"/>
        <source>RLC Steady state response</source>
        <translation>Circuit RLC en régime permanent</translation>
    </message>
    <message>
        <location filename="../main.py" line="75"/>
        <source>RC Transient response</source>
        <translation>Circuit RC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="76"/>
        <source>RL Transient response</source>
        <translation>Circuit RL en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="77"/>
        <source>RLC transient response</source>
        <translation>Circuit RLC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="78"/>
        <source>Frequency Response of Filter Circuit</source>
        <translation>Réponse en fréquence d&apos;un circuit de filtrage</translation>
    </message>
    <message>
        <location filename="../main.py" line="79"/>
        <source>Electromagnetic Induction</source>
        <translation>Induction électromagnétique</translation>
    </message>
    <message>
        <location filename="../main.py" line="83"/>
        <source>Frequency Response of Piezo Buzzer</source>
        <translation>Réponse en fréquence d&apos;un buzzer piézo</translation>
    </message>
    <message>
        <location filename="../main.py" line="84"/>
        <source>Velocity of Sound</source>
        <translation>Vitesse du son</translation>
    </message>
    <message>
        <location filename="../main.py" line="85"/>
        <source>Sound beats</source>
        <translation>Battements sonores</translation>
    </message>
    <message>
        <location filename="../main.py" line="89"/>
        <source>Rod Pendulum with Light barrier</source>
        <translation>Pendule à barre avec une détecteur lumineux</translation>
    </message>
    <message>
        <location filename="../main.py" line="90"/>
        <source>Pendulum Wavefrorm</source>
        <translation>Signal d&apos;un pendule</translation>
    </message>
    <message>
        <location filename="../main.py" line="91"/>
        <source>Driven Pendulum resonance</source>
        <translation>Résonance d&apos;un pendule entretenu</translation>
    </message>
    <message>
        <location filename="../main.py" line="92"/>
        <source>Distance by HY-SRF04 Echo module</source>
        <translation>Distance à l&apos;aide d&apos;un module d&apos;écho SFR04</translation>
    </message>
    <message>
        <location filename="../main.py" line="96"/>
        <source>Temperatue, PT100 Sensor</source>
        <translation>Température, sonde Pt100</translation>
    </message>
    <message>
        <location filename="../main.py" line="97"/>
        <source>Data Logger</source>
        <translation>Enregistreur de données</translation>
    </message>
    <message>
        <location filename="../main.py" line="101"/>
        <source>MPU-6050 Acccn, Velocity and Temp</source>
        <translation>MPU-6050 : Acccn, Vit. et Temp</translation>
    </message>
    <message>
        <location filename="../main.py" line="105"/>
        <source>Read Inputs</source>
        <translation>Lire les entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="106"/>
        <source>Set DC Voltages</source>
        <translation>Régler les tensions continues</translation>
    </message>
    <message>
        <location filename="../main.py" line="107"/>
        <source>Capture Single Input</source>
        <translation>Capturer une seule entrée</translation>
    </message>
    <message>
        <location filename="../main.py" line="108"/>
        <source>Capture Two Inputs</source>
        <translation>Capturer deux entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="109"/>
        <source>Capture Four Inputs</source>
        <translation>Capturer quatre entrées</translation>
    </message>
    <message>
        <location filename="../main.py" line="110"/>
        <source>Triangular Waveform</source>
        <translation>Signal triangulaire</translation>
    </message>
    <message>
        <location filename="../main.py" line="111"/>
        <source>Arbitrary Waveform</source>
        <translation>Signal arbitraire</translation>
    </message>
    <message>
        <location filename="../main.py" line="112"/>
        <source>Waveform Table</source>
        <translation>Table d&apos;ondes</translation>
    </message>
    <message>
        <location filename="../main.py" line="113"/>
        <source>RC Transient</source>
        <translation>RC en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="114"/>
        <source>RL Transient</source>
        <translation>RL en régime transitoire</translation>
    </message>
    <message>
        <location filename="../main.py" line="115"/>
        <source>RC Integration</source>
        <translation>Intégration RC</translation>
    </message>
    <message>
        <location filename="../main.py" line="116"/>
        <source>Clipping with Diode</source>
        <translation>Écrêtage à diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="117"/>
        <source>Clamping with Diode</source>
        <translation>Décaleur à diode</translation>
    </message>
    <message>
        <location filename="../main.py" line="119"/>
        <source>NPN Ib vs IC plot</source>
        <translation>Tracé Ib vs Ic (NPN)</translation>
    </message>
    <message>
        <location filename="../main.py" line="120"/>
        <source>Fourier Transform</source>
        <translation>Transformée de Fourier</translation>
    </message>
    <message>
        <location filename="../main.py" line="121"/>
        <source>Rod Pendulum</source>
        <translation>Pendule pesant</translation>
    </message>
    <message>
        <location filename="../main.py" line="63"/>
        <source>Transistor Amplifier (CE)</source>
        <translation>Amplificateur à transistor (CE)</translation>
    </message>
</context>
<context>
    <name>hello</name>
    <message>
        <location filename="../translate.py" line="81"/>
        <source>Hello</source>
        <translation type="obsolete">Bonjour</translation>
    </message>
</context>
<context>
    <name>helpWin</name>
    <message>
        <location filename="../main.py" line="144"/>
        <source>Help: %s</source>
        <translation>Aide : %s</translation>
    </message>
</context>
</TS>
